@@ -20,8 +20,6 @@ urlpatterns = patterns("",
         views.UserRecommendationAPI().as_view(), name="recommender_no_format_api"),
     url(r"^recommend/(?P<number_of_recommendations>[0-9]+)/(?P<user_external_id>\w[\w/-]*).(?P<data_format>\w+)$",
         views.UserRecommendationAPI().as_view(), name="recommender_file_api"),
-    url(r"^recommend/(?P<number_of_recommendations>[0-9]+)/$",
-        views.UserRecommendationAPI().as_view(), name="recommender_no_format_api"),
     url(r"^user-items/(?P<user_external_id>\w[\w/-]*)/(?P<data_format>\w+)/$", views.UserItemsAPI().as_view(),
         name="user_item_api"),
     url(r"^user-items/(?P<user_external_id>\w[\w/-]*)/$", views.UserItemsAPI().as_view(),
@@ -30,6 +28,5 @@ urlpatterns = patterns("",
         name="user_items_file_api"),
     url(r"^users/(?P<data_format>\w+)/$", views.UsersAPI().as_view(), name="user_api"),
     url(r"^users/$", views.UsersAPI().as_view(), name="user_no_format_api"),
-    url(r"^users.(?P<data_format>\w+)$", views.UsersAPI().as_view(), name="user_file_api"),
-    url(r"^localcachetest/(?P<token>[0-9]+)/$", views.LocalCacheTest().as_view(), name="local_cache_test_api")
+    url(r"^users.(?P<data_format>\w+)$", views.UsersAPI().as_view(), name="user_file_api")
 )
\ No newline at end of file
