@@ -1,16 +1,19 @@
 #! -*- encoding: utf-8 -*-
 
 from __future__ import division, absolute_import, print_function
-import os
-from concurrent.futures import ThreadPoolExecutor, TimeoutError
-from django.conf import settings
+#import os
+from concurrent.futures import ThreadPoolExecutor  # , TimeoutError
+#from django.conf import settings
 from django.core.cache import get_cache
 import functools
-import atexit
+#import atexit
 import itertools
 import warnings
-import random
-import logging
+#import random
+#import logging
+import sys
+import traceback
+#import recommendation.settings
 try:
     from uwsgi import lock, i_am_the_spooler, unlock, mule_msg
 except ImportError:
@@ -21,10 +24,28 @@ except ImportError:
 __author__ = "joaonrb"
 
 
+class ThreadPoolExecutorStackTraced(ThreadPoolExecutor):
+
+    def submit(self, fn, *args, **kwargs):
+        """Submits the wrapped function instead of `fn`"""
+
+        return super(ThreadPoolExecutorStackTraced, self).submit(
+            self._function_wrapper, fn, *args, **kwargs)
+
+    def _function_wrapper(self, fn, *args, **kwargs):
+        """Wraps `fn` in order to preserve the traceback of any kind of
+        raised exception
+
+        """
+        try:
+            return fn(*args, **kwargs)
+        except Exception:
+            raise sys.exc_info()[0](traceback.format_exc())
+
 #thread_pool = ThreadPoolExecutor(max_workers=getattr(recommendation.settings, "MAX_THREADS", 2))
-clone_pool = ThreadPoolExecutor(max_workers=1)
+# clone_pool = ThreadPoolExecutorStackTraced(max_workers=1)
 #atexit.register(thread_pool.shutdown)
-atexit.register(clone_pool.shutdown)
+# atexit.register(clone_pool.shutdown)
 
 
 #class ExecuteInBackground(object):
@@ -118,44 +139,48 @@ class Cached(object):
         return decorated
 
 
-class ContingencyProtocol(object):
-    """
-    Execute in threading pool
-    """
-    def __init__(self):
-        self.__name__ = "ContingencyProtocol"
-        self.decorator = self.no_contingency if int(os.environ.get("FRAPPE_TEST", 0)) else self.with_contingency
+# class ContingencyProtocol(object):
+#    """
+#    Execute in threading pool
+#    """
+#    def __init__(self):
+#        self.__name__ = "ContingencyProtocol"
+#        self.decorator = self.no_contingency if int(os.environ.get("FRAPPE_TEST", 0)) else self.with_contingency
 
-    def with_contingency(self, function):
-        """
-        The call of the view.
-        """
+#    def with_contingency(self, function):
+#        """
+#        The call of the view.
+#        """
 
-        def decorated(self, user, n=10):
-            future = clone_pool.submit(function, self, user, n)
-            try:
-                result = future.result(getattr(settings, "RESPONSE_TIMEOUT", 150./1000.))
-            except (TimeoutError, Exception):
-                future.cancel()
-                logging.log(logging.ERROR, "TimeOut error: Contingency Protocol delivered the recommendation")
-                result = random.sample(getattr(settings, "CONTINGENCY_ITEMS", SAMPLE), n)
-            return result
-        return decorated
+#        def decorated(self, user, n=10):
+#            future = clone_pool.submit(function, self, user, n)
+#            try:
+#                result = future.result(getattr(settings, "RESPONSE_TIMEOUT", 150./1000.))
+#            except TimeoutError:
+#                future.cancel()
+#                logging.error("TimeOut error: Contingency Protocol delivered the recommendation")
+#                result = random.sample(getattr(settings, "CONTINGENCY_ITEMS", SAMPLE), n)
+#            except Exception:
+#                future.cancel()
+#                logging.error(traceback.format_exc())
+#                result = random.sample(getattr(settings, "CONTINGENCY_ITEMS", SAMPLE), n)
+#            return result
+#        return decorated
 
-    def no_contingency(self, function):
-        """
-        The call of the view.
-        """
+#    def no_contingency(self, function):
+#        """
+#        The call of the view.
+#        """
+#
+#        def decorated(self, user, n=10):
+#            return function(self, user, n)
+#        return decorated
 
-        def decorated(self, user, n=10):
-            return function(self, user, n)
-        return decorated
-
-    def __call__(self, function):
-        """
-        The call of the view.
-        """
-        return self.decorator(function)
+#    def __call__(self, function):
+#        """
+#        The call of the view.
+#        """
+#        return self.decorator(function)
 
 SAMPLE = ["364927",
           "409126",
