@@ -7,10 +7,12 @@ Implementation of the simple diversity for
 .. moduleauthor:: joaonrb <joaonrb@gmail.com>
 
 """
-__author__ = "joaonrb"
 
+from __future__ import division, absolute_import, print_function
 from recommendation.diversity.models import Genre, ItemGenre
 
+__author__ = "joaonrb"
+
 
 def weighted_p(p_global, p_local, alpha):
     """
@@ -38,8 +40,14 @@ class SimpleDiversity(object):
         self.counter = {}
         for genre_id in Genre.get_all_genres():
             genre = Genre.get_genre_by_id(genre_id)
-            p_global = genre.count_items / number_items
-            p_local = user_genres.get(genre, 0.) / user_items_count if user_items_count else 0.
+            try:
+                p_global = genre.count_items / float(number_items)
+            except ZeroDivisionError:
+                p_global = 0.
+            try:
+                p_local = user_genres.get(genre, 0.) / float(user_items_count)
+            except ZeroDivisionError:
+                p_local = 0.
             self.counter[genre.pk] = int(weighted_p(p_global, p_local, alpha_constant) * size)
 
     def __call__(self, recommendation, item_id):
@@ -51,10 +59,10 @@ class SimpleDiversity(object):
                 dropped += 1
         # Change "<" to "<=" improve greatly
         if dropped <= len(genres):
-            #recommendation.append(item)
+            # recommendation.append(item)
             return True
         return False
-        #return recommendation
+        # return recommendation
 
 
 class SimpleDiversityReRanker(object):
@@ -89,13 +97,7 @@ class SimpleDiversityReRanker(object):
         diversity = SimpleDiversity(recommendation, size, user, self.alpha_constant, self.lambda_constant)
         new_recommendation = []
         dropped_items = []
-        #for item in recommendation[:int(2*len(recommendation)/3)]:
         for item_id in recommendation:
-            #new_recommendation0 = diversity(new_recommendation, item)
-            #if len(new_recommendation0) != len(new_recommendation) + 1:
-            #    dropped_items.append(item)
-            #else:
-            #    new_recommendation = new_recommendation0
             if diversity(new_recommendation, item_id):
                 new_recommendation.append(item_id)
             else:
