@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 from django.conf.urls import patterns, include, url
 from health_check.plugins import plugin_dir
-from recommendation.backends import CheckDefaultCacheBackend, CheckOwnedItemsCacheBackend
+from recommendation.backends import CheckDefaultCacheBackend, CheckOwnedItemsCacheBackend, CheckDatabaseCacheBackend
 #from django.contrib import admin
 #admin.autodiscover()
 
 
+plugin_dir.register(CheckDatabaseCacheBackend)
 plugin_dir.register(CheckDefaultCacheBackend)
 plugin_dir.register(CheckOwnedItemsCacheBackend)
 
