@@ -26,11 +26,12 @@ TensorCoFi.load_to_cache()
 
 
 if "recommendation.language" in settings.INSTALLED_APPS:
-    from recommendation.language.models import Locale
+    from recommendation.language.models import Locale, Region
     Locale.load_to_cache()
+    Region.load_to_cache()
 
 
-#if "recommendation.simple_logging" in settings.INSTALLED_APPS:
+#if "recommendation.simple_logging" in recommendation.settings.INSTALLED_APPS:
 #    print("Loading logs to cache...")
 #    from recommendation.simple_logging.models import LogEntry
 #    LogEntry.load_to_cache()
